==> customgpt_client-1.2.0-py3-none-any.whl: customgpt_client/api/conversations/delete_conversation.py <==
import json
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import requests

from ... import errors
from ...models.delete_conversation_response_200 import DeleteConversationResponse200
from ...models.delete_conversation_response_400 import DeleteConversationResponse400
from ...models.delete_conversation_response_401 import DeleteConversationResponse401
from ...models.delete_conversation_response_404 import DeleteConversationResponse404
from ...models.delete_conversation_response_500 import DeleteConversationResponse500
from ...types import Response


def _get_kwargs(
    project_id: int,
    session_id: str,
    *,
    client: {},
) -> Dict[str, Any]:
    url = "{}/api/v1/projects/{projectId}/conversations/{sessionId}".format(
        client.base_url, projectId=project_id, sessionId=session_id
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "delete",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "allow_redirects": client.follow_redirects,
    }


def _parse_response(
    *, client: {}, response: None
) -> Optional[
    Union[
        DeleteConversationResponse200,
        DeleteConversationResponse400,
        DeleteConversationResponse401,
        DeleteConversationResponse404,
        DeleteConversationResponse500,
    ]
]:
    if response.status_code == HTTPStatus.OK:
        response_200 = DeleteConversationResponse200.from_dict(json.loads(response.text))

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = DeleteConversationResponse400.from_dict(json.loads(response.text))

        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = DeleteConversationResponse401.from_dict(json.loads(response.text))

        return response_401
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = DeleteConversationResponse404.from_dict(json.loads(response.text))

        return response_404
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
        response_500 = DeleteConversationResponse500.from_dict(json.loads(response.text))

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: {}, response: None, content: Optional[bytes] = None
) -> Response[
    Union[
        DeleteConversationResponse200,
        DeleteConversationResponse400,
        DeleteConversationResponse401,
        DeleteConversationResponse404,
        DeleteConversationResponse500,
    ]
]:
    parse = _parse_response(client=client, response=response)
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content if content is None else content,
        headers=response.headers,
        parsed=parse,
    )


def sync_detailed(
    project_id: int,
    session_id: str,
    *,
    client: {},
):
    """Delete a conversation.

     Delete a conversation within a project identified by its unique projectId and sessionId. This
    endpoint allows you to remove a specific conversation from the project, permanently deleting all
    associated messages. By providing the projectId and sessionId, you can target the conversation to be
    deleted, ensuring the removal of all conversation-related data.
    Here is an example to delete a conversation: [API](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/Update_Delete_a_conversation.ipynb) [SDK](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/SDK_Update_Delete_a_conversation.ipynb).

    Args:
        project_id (int):
        session_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[DeleteConversationResponse200, DeleteConversationResponse400, DeleteConversationResponse401, DeleteConversationResponse404, DeleteConversationResponse500]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        session_id=session_id,
        client=client,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: int,
    session_id: str,
    *,
    client: {},
) -> Optional[
    Union[
        DeleteConversationResponse200,
        DeleteConversationResponse400,
        DeleteConversationResponse401,
        DeleteConversationResponse404,
        DeleteConversationResponse500,
    ]
]:
    """Delete a conversation.

     Delete a conversation within a project identified by its unique projectId and sessionId. This
    endpoint allows you to remove a specific conversation from the project, permanently deleting all
    associated messages. By providing the projectId and sessionId, you can target the conversation to be
    deleted, ensuring the removal of all conversation-related data.
    Here is an example to delete a conversation: [API](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/Update_Delete_a_conversation.ipynb) [SDK](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/SDK_Update_Delete_a_conversation.ipynb).

    Args:
        project_id (int):
        session_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[DeleteConversationResponse200, DeleteConversationResponse400, DeleteConversationResponse401, DeleteConversationResponse404, DeleteConversationResponse500]
    """

    return sync_detailed(
        project_id=project_id,
        session_id=session_id,
        client=client,
    ).parsed


async def asyncio_detailed(
    project_id: int,
    session_id: str,
    *,
    client: {},
) -> Response[
    Union[
        DeleteConversationResponse200,
        DeleteConversationResponse400,
        DeleteConversationResponse401,
        DeleteConversationResponse404,
        DeleteConversationResponse500,
    ]
]:
    kwargs = _get_kwargs(
        project_id=project_id,
        session_id=session_id,
        client=client,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: int,
    session_id: str,
    *,
    client: {},
) -> Optional[
    Union[
        DeleteConversationResponse200,
        DeleteConversationResponse400,
        DeleteConversationResponse401,
        DeleteConversationResponse404,
        DeleteConversationResponse500,
    ]
]:
    """Delete a conversation.

     Delete a conversation within a project identified by its unique projectId and sessionId. This
    endpoint allows you to remove a specific conversation from the project, permanently deleting all
    associated messages. By providing the projectId and sessionId, you can target the conversation to be
    deleted, ensuring the removal of all conversation-related data.
    Here is an example to delete a conversation: [API](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/Update_Delete_a_conversation.ipynb) [SDK](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/SDK_Update_Delete_a_conversation.ipynb).

    Args:
        project_id (int):
        session_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[DeleteConversationResponse200, DeleteConversationResponse400, DeleteConversationResponse401, DeleteConversationResponse404, DeleteConversationResponse500]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            session_id=session_id,
            client=client,
        )
    ).parsed

==> customgpt_client-1.2.5-py3-none-any.whl: customgpt_client/api/conversations/delete_conversation.py <==
import json
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import requests

from ... import errors
from ...models.delete_conversation_response_200 import DeleteConversationResponse200
from ...models.delete_conversation_response_400 import DeleteConversationResponse400
from ...models.delete_conversation_response_401 import DeleteConversationResponse401
from ...models.delete_conversation_response_404 import DeleteConversationResponse404
from ...models.delete_conversation_response_500 import DeleteConversationResponse500
from ...types import Response


def _get_kwargs(
    project_id: int,
    session_id: str,
    *,
    client: {},
) -> Dict[str, Any]:
    url = "{}/api/v1/projects/{projectId}/conversations/{sessionId}".format(
        client.base_url, projectId=project_id, sessionId=session_id
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "delete",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "allow_redirects": client.follow_redirects,
    }


def _parse_response(*, client: {}, response: None) -> Optional[
    Union[
        DeleteConversationResponse200,
        DeleteConversationResponse400,
        DeleteConversationResponse401,
        DeleteConversationResponse404,
        DeleteConversationResponse500,
    ]
]:
    if response.status_code == HTTPStatus.OK:
        response_200 = DeleteConversationResponse200.from_dict(json.loads(response.text))

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = DeleteConversationResponse400.from_dict(json.loads(response.text))

        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = DeleteConversationResponse401.from_dict(json.loads(response.text))

        return response_401
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = DeleteConversationResponse404.from_dict(json.loads(response.text))

        return response_404
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
        response_500 = DeleteConversationResponse500.from_dict(json.loads(response.text))

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: {}, response: None, content: Optional[bytes] = None) -> Response[
    Union[
        DeleteConversationResponse200,
        DeleteConversationResponse400,
        DeleteConversationResponse401,
        DeleteConversationResponse404,
        DeleteConversationResponse500,
    ]
]:
    parse = _parse_response(client=client, response=response)
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content if content is None else content,
        headers=response.headers,
        parsed=parse,
    )


def sync_detailed(
    project_id: int,
    session_id: str,
    *,
    client: {},
):
    """Delete a conversation.

     Delete a conversation within a project identified by its unique projectId and sessionId. This
    endpoint allows you to remove a specific conversation from the project, permanently deleting all
    associated messages. By providing the projectId and sessionId, you can target the conversation to be
    deleted, ensuring the removal of all conversation-related data.
    Here is an example to delete a conversation: [API](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/Update_Delete_a_conversation.ipynb) [SDK](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/SDK_Update_Delete_a_conversation.ipynb).

    Args:
        project_id (int):
        session_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[DeleteConversationResponse200, DeleteConversationResponse400, DeleteConversationResponse401, DeleteConversationResponse404, DeleteConversationResponse500]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        session_id=session_id,
        client=client,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: int,
    session_id: str,
    *,
    client: {},
) -> Optional[
    Union[
        DeleteConversationResponse200,
        DeleteConversationResponse400,
        DeleteConversationResponse401,
        DeleteConversationResponse404,
        DeleteConversationResponse500,
    ]
]:
    """Delete a conversation.

     Delete a conversation within a project identified by its unique projectId and sessionId. This
    endpoint allows you to remove a specific conversation from the project, permanently deleting all
    associated messages. By providing the projectId and sessionId, you can target the conversation to be
    deleted, ensuring the removal of all conversation-related data.
    Here is an example to delete a conversation: [API](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/Update_Delete_a_conversation.ipynb) [SDK](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/SDK_Update_Delete_a_conversation.ipynb).

    Args:
        project_id (int):
        session_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[DeleteConversationResponse200, DeleteConversationResponse400, DeleteConversationResponse401, DeleteConversationResponse404, DeleteConversationResponse500]
    """

    return sync_detailed(
        project_id=project_id,
        session_id=session_id,
        client=client,
    ).parsed


async def asyncio_detailed(
    project_id: int,
    session_id: str,
    *,
    client: {},
) -> Response[
    Union[
        DeleteConversationResponse200,
        DeleteConversationResponse400,
        DeleteConversationResponse401,
        DeleteConversationResponse404,
        DeleteConversationResponse500,
    ]
]:

    kwargs = _get_kwargs(
        project_id=project_id,
        session_id=session_id,
        client=client,
    )

    response = requests.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: int,
    session_id: str,
    *,
    client: {},
) -> Optional[
    Union[
        DeleteConversationResponse200,
        DeleteConversationResponse400,
        DeleteConversationResponse401,
        DeleteConversationResponse404,
        DeleteConversationResponse500,
    ]
]:
    """Delete a conversation.

     Delete a conversation within a project identified by its unique projectId and sessionId. This
    endpoint allows you to remove a specific conversation from the project, permanently deleting all
    associated messages. By providing the projectId and sessionId, you can target the conversation to be
    deleted, ensuring the removal of all conversation-related data.
    Here is an example to delete a conversation: [API](https://github.com/Poll-The-People/customgpt-
    cookbook/blob/main/examples/Update_Delete_a_conversation.ipynb) [SDK](https://github.com/Poll-The-
    People/customgpt-cookbook/blob/main/examples/SDK_Update_Delete_a_conversation.ipynb).

    Args:
        project_id (int):
        session_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[DeleteConversationResponse200, DeleteConversationResponse400, DeleteConversationResponse401, DeleteConversationResponse404, DeleteConversationResponse500]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            session_id=session_id,
            client=client,
        )
    ).parsed
